==> create-gx-cli-0.0.5.tgz: package/template-mobile-vant-cli/src/components/PageContainer/index.tsx <==
import { defineComponent, toRefs, watch } from 'vue'
import { usePageLoading } from '@gx-mobile/hooks/web'
import ProSkeleton from './ProSkeleton'
import styles from './style.module.less'
import type { SetLoadingParams } from '@gx-mobile/hooks/web/usePageLoading'

export type PageLoadingTpe = 'toast' | 'skeleton'

type ChangeLoadingParams<T> = Omit<SetLoadingParams<T>, 'type'> & {
  hiddenSlot?: boolean;
}

const PageContainer = defineComponent({
  name: 'GProPageContainer',
  inheritAttrs: false,
  props: {
    loading: Boolean as PropType<boolean>,
    hiddenSlot: {
      type: Boolean as PropType<boolean>,
      default: true
    },
    loadingMsg: {
      type: String as PropType<string>,
      default: '加载中'
    },
    loadingType: {
      type: String as PropType<PageLoadingTpe>,
      default: 'toast'
    },
    bgcolor: {
      type: String as PropType<string>,
      default: '#fafafa'
    }
  },
  emits: [ 'update:loading' ],
  setup(props, { slots, expose, emit }) {
    const { loading: loadingRef, loadingType, loadingMsg, hiddenSlot } = toRefs(props)

    const initStatus = ref(true)

    const hiddenSlotRef = ref(props.hiddenSlot)

    const [ loading, setLoading ] = usePageLoading({
      defaultType: loadingType.value,
      defaultMessage: loadingMsg.value,
      defaultLoading: loadingRef.value
    })

    watch(() => loading.value, (val) => {
      if (initStatus.value && val) initStatus.value = false
      emit('update:loading', val)
    }, {
      deep: true,
      immediate: true
    })

    watch(() => loadingRef.value, (val) => {
      if (loadingType.value === 'toast') {
        setLoading({
          value: val,
          type: loadingType.value,
          message: loadingMsg.value
        })
      } else if (initStatus.value || !val) {
        setLoading({
          value: val,
          type: loadingType.value,
          message: loadingMsg.value
        })
      }
    })

    watch(() => hiddenSlot.value, (val) => {
      hiddenSlotRef.value = val
    }, {
      immediate: true
    })

    const changeLoading = ({
      value,
      message,
      hiddenSlot
    }: ChangeLoadingParams<boolean>) => {
      if (loadingType.value === 'toast') {
        hiddenSlotRef.value = hiddenSlot
        setLoading({ value, message, type: loadingType.value })
      }
    }

    expose({
      toggleLoading: changeLoading
    })

    return () => {
      return (
        <div class={styles.pageContainer} style={{ backgroundColor: props.bgcolor }}>
          <div class={styles.pageContainerWrapper}>
            {
              loadingType.value === 'skeleton'
                ? (
                  <ProSkeleton line={3} loading={loading.value}>
                    {slots.default?.()}
                  </ProSkeleton>
                )
                : ((!loading.value || !hiddenSlotRef.value) && <>{slots.default?.()}</>)
            }
          </div>
        </div>
      )
    }
  }
})

export default PageContainer

==> create-gx-cli-0.1.11.tgz: package/template-mobile-vant-cli/src/components/PageContainer/index.tsx <==
import { defineComponent, toRefs, watch } from 'vue'
import { usePageLoading } from '@gx-mobile/hooks/web'
import ProSkeleton from './ProSkeleton'
import styles from './style.module.less'
import type { SetLoadingParams } from '@gx-mobile/hooks/web/usePageLoading'

export type PageLoadingTpe = 'toast' | 'skeleton'

type ChangeLoadingParams<T> = Omit<SetLoadingParams<T>, 'type'> & {
  hiddenSlot?: boolean;
}

const PageContainer = defineComponent({
  name: 'GProPageContainer',
  inheritAttrs: false,
  props: {
    loading: Boolean as VuePropType<boolean>,
    hiddenSlot: {
      type: Boolean as VuePropType<boolean>,
      default: true
    },
    loadingMsg: {
      type: String as VuePropType<string>,
      default: '加载中'
    },
    loadingType: {
      type: String as VuePropType<PageLoadingTpe>,
      default: 'toast'
    },
    bgcolor: {
      type: String as VuePropType<string>,
      default: '#fafafa'
    }
  },
  emits: [ 'update:loading' ],
  setup(props, { slots, expose, emit }) {
    const { loading: loadingRef, loadingType, loadingMsg, hiddenSlot } = toRefs(props)

    const initStatus = ref(true)

    const hiddenSlotRef = ref(props.hiddenSlot)

    const [ loading, setLoading ] = usePageLoading({
      defaultType: loadingType.value,
      defaultMessage: loadingMsg.value,
      defaultLoading: loadingRef.value
    })

    watch(() => loading.value, (val) => {
      if (initStatus.value && val)
        initStatus.value = false
      emit('update:loading', val)
    }, {
      deep: true,
      immediate: true
    })

    watch(() => loadingRef.value, (val) => {
      if (loadingType.value === 'toast') {
        setLoading({
          value: val,
          type: loadingType.value,
          message: loadingMsg.value
        })
      } else if (initStatus.value || !val) {
        setLoading({
          value: val,
          type: loadingType.value,
          message: loadingMsg.value
        })
      }
    })

    watch(() => hiddenSlot.value, (val) => {
      hiddenSlotRef.value = val
    }, {
      immediate: true
    })

    const changeLoading = ({
      value,
      message,
      hiddenSlot
    }: ChangeLoadingParams<boolean>) => {
      if (loadingType.value === 'toast') {
        hiddenSlotRef.value = hiddenSlot
        setLoading({ value, message, type: loadingType.value })
      }
    }

    expose({
      toggleLoading: changeLoading
    })

    return () => {
      return (
        <div class={styles.pageContainer} style={{ backgroundColor: props.bgcolor }}>
          <div class={styles.pageContainerWrapper}>
            {
              loadingType.value === 'skeleton'
                ? (
                  <ProSkeleton line={3} loading={loading.value}>
                    {slots.default?.()}
                  </ProSkeleton>
                )
                : ((!loading.value || !hiddenSlotRef.value) && <>{slots.default?.()}</>)
            }
          </div>
        </div>
      )
    }
  }
})

export default PageContainer
